@@ -10,16 +10,15 @@ setMethod(
   signature = c(object = "data.frame"),
   definition = function(object, center = TRUE, scale = TRUE, rank = NULL,
                         sup_row = NULL, sup_col = NULL, sup_quali = NULL,
-                        weight_row = NULL, weight_col = NULL) {
+                        weight_row = NULL, weight_col = NULL, autodetect = FALSE) {
     ## Remove non-numeric variables, if any
     clean <- drop_variable(object, f = is.numeric, negate = TRUE,
-                           sup = sup_col, extra = sup_quali,
+                           sup = sup_col, extra = sup_quali, auto = autodetect,
                            what = "qualitative")
 
     ## Compute PCA
-    object <- as.matrix(clean$data)
     results <- methods::callGeneric(
-      object = object, center = center, scale = scale,
+      object = clean$data, center = center, scale = scale,
       rank = rank, sup_row = sup_row, sup_col = clean$sup,
       weight_row = weight_row, weight_col = weight_col
     )
