@@ -15,10 +15,10 @@ if (at_home()) {
   X <- pca(countries, scale = FALSE, weight_row = row_w, weight_col = col_w)
 
   # Row-metric-preserving biplot
-  plot_biplot_row <- function() biplot(X, type = "form", labels = NULL)
+  plot_biplot_row <- function() biplot(X, type = "form", labels = NULL, lwd = 2)
   expect_snapshot_plot(plot_biplot_row, "PCA_biplot_row")
 
   # Column-metric-preserving biplot
-  plot_biplot_col <- function() biplot(X, type = "covariance", labels = NULL)
+  plot_biplot_col <- function() biplot(X, type = "covariance", labels = NULL, lwd = 2)
   expect_snapshot_plot(plot_biplot_col, "PCA_biplot_column")
 }
